from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Boolean, Directory

Macs2_Bdgopt_V0_1_0 = CommandToolBuilder(tool="macs2_bdgopt", base_command=["macs2", "bdgopt"], inputs=[ToolInput(tag="in_i_file", input_type=File(optional=True), prefix="--ifile", doc=InputDocumentation(doc="MACS score in bedGraph. Note: this must be a bedGraph\nfile covering the ENTIRE genome. REQUIRED")), ToolInput(tag="in_method", input_type=String(optional=True), prefix="--method", doc=InputDocumentation(doc="Method to modify the score column of bedGraph file.\nAvailable choices are: multiply, add, max, min, or\np2q. 1) multiply, the EXTRAPARAM is required and will\nbe multiplied to the score column. If you intend to\ndivide the score column by X, use value of 1/X as\nEXTRAPARAM. 2) add, the EXTRAPARAM is required and\nwill be added to the score column. If you intend to\nsubtract the score column by X, use value of -X as\nEXTRAPARAM. 3) max, the EXTRAPARAM is required and\nwill take the maximum value between score and the\nEXTRAPARAM. 4) min, the EXTRAPARAM is required and\nwill take the minimum value between score and the\nEXTRAPARAM. 5) p2q, this will convert p-value scores\nto q-value scores using Benjamini-Hochberg process.\nThe EXTRAPARAM is not required. This method assumes\nthe scores are -log10 p-value from MACS2. Any other\ntypes of score will cause unexpected errors.")), ToolInput(tag="in_extra_parameter_method", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="[EXTRAPARAM [EXTRAPARAM ...]], --extra-param [EXTRAPARAM [EXTRAPARAM ...]]\nThe extra parameter for METHOD. Check the detail of -m\noption.")), ToolInput(tag="in_outdir", input_type=Directory(optional=True), prefix="--outdir", doc=InputDocumentation(doc="If specified all output files will be written to that\ndirectory. Default: the current working directory")), ToolInput(tag="in_output_bedgraph_filename", input_type=File(optional=True), prefix="--ofile", doc=InputDocumentation(doc="Output BEDGraph filename.\n")), ToolInput(tag="in_optional_arguments", input_type=String(), position=0, doc=InputDocumentation(doc="optional arguments:"))], outputs=[ToolOutput(tag="out_outdir", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_outdir", type_hint=File()), doc=OutputDocumentation(doc="If specified all output files will be written to that\ndirectory. Default: the current working directory")), ToolOutput(tag="out_output_bedgraph_filename", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_bedgraph_filename", type_hint=File()), doc=OutputDocumentation(doc="Output BEDGraph filename.\n"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Macs2_Bdgopt_V0_1_0().translate("wdl", allow_empty_container=True)

